@@ -25,8 +25,6 @@ import pytest
 import sqlalchemy
 import sqlalchemy.pool
 
-from six.moves import urllib_parse
-
 
 def pytest_addoption(parser):
     group = parser.getgroup("warehouse")
@@ -67,7 +65,7 @@ def _database_url(request):
             and not database_url_option):
         pytest.skip("No database provided")
 
-    # Configure our engine so that we can create a database
+    # Configure our engine so that we can empty the database
     database_url = (
         database_url_option or database_url_environ or database_url_default
     )
@@ -77,35 +75,22 @@ def _database_url(request):
         poolclass=sqlalchemy.pool.NullPool
     )
 
-    # Make a random database name that doesn't exist
-    name = _get_name()
-    while not _check_name(engine, name):
-        name = _get_name()
-
-    # Create the database
-    with engine.connect() as conn:
-        conn.execute("CREATE DATABASE {} ENCODING 'UTF8'".format(name))
-
-    # Create a new database_url with the name replaced
-    parsed = urllib_parse.urlparse(database_url)
-    test_database_url = urllib_parse.urlunparse(
-        parsed[:2] + ("/" + name,) + parsed[3:]
-    )
-
     # Create the database schema
-    test_engine = sqlalchemy.create_engine(
-        test_database_url,
+    engine = sqlalchemy.create_engine(
+        database_url,
         poolclass=sqlalchemy.pool.NullPool,
     )
     app = Warehouse.from_yaml(
         override={
-            "database": {"url": test_database_url},
+            "database": {"url": database_url},
             "search": {"hosts": []},
         },
-        engine=test_engine,
+        engine=engine,
         redis=False,
     )
     with app.engine.connect() as conn:
+        conn.execute("DROP SCHEMA public CASCADE")
+        conn.execute("CREATE SCHEMA public")
         conn.execute("CREATE EXTENSION IF NOT EXISTS citext")
     alembic_cfg = alembic.config.Config()
     alembic_cfg.set_main_option(
@@ -114,23 +99,9 @@ def _database_url(request):
     )
     alembic_cfg.set_main_option("url", app.config.database.url)
     alembic.command.upgrade(alembic_cfg, "head")
-    test_engine.dispose()
+    engine.dispose()
 
-    # Drop the database at the end of the session
-    def _drop_database():
-        with engine.connect() as conn:
-            # Terminate all open connections to the test database
-            conn.execute(
-                """SELECT pg_terminate_backend(pid)
-                   FROM pg_stat_activity
-                   WHERE datname = %s
-                """,
-                [name],
-            )
-            conn.execute("DROP DATABASE {}".format(name))
-    request.addfinalizer(_drop_database)
-
-    return test_database_url
+    return database_url
 
 
 @pytest.fixture(scope="session")
